@@ -71,13 +71,14 @@ createExtent <- function(x, offset = NULL) {
   } else {
     if (inherits(x, "Raster")) {
       ext <- raster::extent(
-        raster::projectExtent(x, crs = llcrs))
+        raster::projectExtent(x, crs = sp::CRS("+init=epsg:4326")))
     } else if (inherits(x, "Spatial")) {
       ext <- raster::extent(raster::xmin(x),
                             raster::xmax(x),
                             raster::ymin(x),
                             raster::ymax(x))
-    } else if (inherits(x, "sfc") | inherits(x, "sf") | inherits(x, "XY")) {
+    } else if (inherits(x, "sfc") | inherits(x, "sf") |
+               inherits(x, "XY") | inherits(x, "stars")) {
       bb <- sf::st_bbox(x)
       ext <- raster::extent(bb[1], bb[3], bb[2], bb[4])
     }
@@ -192,7 +193,7 @@ getProjection <- function(x) {
   if (inherits(x, c("Raster", "Spatial"))) {
     prj <- raster::projection(x)
   } else {
-    prj <- sf::st_crs(x)[["proj4string"]]
+    prj <- sf::st_crs(x)$proj4string
   }
 
   return(prj)
@@ -221,12 +222,12 @@ extendLimits <- function(lim, length = 1, prop = 0.07) {
 }
 
 
-circleRadius <- function(x, radius = 6, min.rad = 3, max.rad = 15) {
+circleRadius <- function(x, radius = 6, min.rad = 3, max.rad = 15, na.rad = 2, ...) {
 
   if (is.character(radius)) {
     rad <- scales::rescale(as.numeric(x[[radius]]),
                            to = c(min.rad, max.rad))
-    rad[is.na(rad)] = 1
+    rad[is.na(rad)] = na.rad
   } else rad <- radius
   return(rad)
 }
@@ -246,9 +247,9 @@ makeLayerName = function(x, zcol = NULL, up = 3) {
 
 
 makeListLayerNames = function(x, layer.name) {
-  if (length(layer.name) == length(x)) {
+  if (length(layer.name) == length(x) & !(is.list(x))) {
     lnms = layer.name
-  } else if (!is.null(names(x))) {
+  } else if (is.list(x) & !(is.null(names(x)))) {
     lnms = names(x)
   } else {
     chr = gsub(utils::glob2rx("*list(*"), "", layer.name)
