@@ -49,53 +49,21 @@ addStarsImage <- function(map,
                           project = FALSE,
                           method = c("bilinear", "ngb"),
                           maxBytes = 4 * 1024 * 1024) {
-  stopifnot(inherits(x, "stars"))
-  if (is.null(group)) group = "stars"
-  if (is.null(layerId)) layerId = group
-  if (project) {
-    projected <- sf::st_transform(x, crs = 3857)
-  } else {
-    projected <- x
-  }
-  # bounds <- raster::extent(raster::projectExtent(raster::projectExtent(x, crs = sp::CRS(epsg3857)), crs = sp::CRS(epsg4326)))
-  bb = sf::st_as_sfc(sf::st_bbox(projected))
-  bounds = as.numeric(sf::st_bbox(sf::st_transform(bb, 4326)))
-  if (!is.function(colors)) {
-    colors <- leaflet::colorNumeric(colors, domain = NULL,
-                                    na.color = "#00000000", alpha = TRUE)
-  }
-  if(length(dim(projected)) == 2) {
-    layer = projected[[1]]
-  } else {
-    layer = projected[[1]][, , band]
-  }
-  tileData <- as.numeric(layer) %>%
-    colors() %>% grDevices::col2rgb(alpha = TRUE) %>% as.raw()
-  dim(tileData) <- c(4, as.numeric(nrow(projected)), as.numeric(ncol(projected)))
-  pngData <- png::writePNG(tileData)
-  if (length(pngData) > maxBytes) {
-    stop("Raster image too large; ",
-         length(pngData),
-         " bytes is greater than maximum ",
-         maxBytes,
-         " bytes")
-  }
-  encoded <- base64enc::base64encode(pngData)
-  uri <- paste0("data:image/png;base64,", encoded)
-  latlng <- list(
-    list(bounds[4], bounds[1]),
-    list(bounds[2], bounds[3])
-  )
-  # map$dependencies <- c(map$dependencies,
-  #                       starsDataDependency(jFn = pathDatFn,
-  #                                           counter = 1,
-  #                                           group = jsgroup))
-  leaflet::invokeMethod(map, getMapData(map), "addRasterImage", uri, latlng,
-                        opacity, attribution, layerId, group) %>%
-    leaflet::expandLimits(c(bounds[2], bounds[4]),
-                          c(bounds[1], bounds[3]))
-}
+  .Deprecated(new = "leafem::addStarsImage", package = "mapview",
+              old = "mapview::addStarsImage")
 
+  leafem::addStarsImage(map = map,
+                        x = x,
+                        band = band,
+                        colors = colors,
+                        opacity = opacity,
+                        attribution = attribution,
+                        layerId = layerId,
+                        group = group,
+                        project = project,
+                        method = method,
+                        maxBytes = maxBytes)
+}
 
 leaflet_stars = function(x,
                          band,
@@ -105,7 +73,6 @@ leaflet_stars = function(x,
                          at,
                          na.color,
                          use.layer.names,
-                         values,
                          map.types,
                          alpha.regions,
                          legend,
@@ -139,7 +106,7 @@ leaflet_stars = function(x,
     #           gdal = TRUE,
     #           ...)
   } else {
-    is.fact = FALSE # raster::is.factor(x)
+    is.fact = is.factor(x[[1]]) # raster::is.factor(x)
     # ext = raster::extent(raster::projectExtent(x, crs = llcrs))
     m = initMap(map, map.types, sf::st_crs(x)$proj4string, viewer.suppress = viewer.suppress)
     # x = rasterCheckSize(x, maxpixels = maxpixels)
@@ -147,23 +114,25 @@ leaflet_stars = function(x,
     ext = createExtent(sf::st_transform(sf::st_as_sfc(sf::st_bbox(x)), crs = 4326))
     # if (!is.na(raster::projection(x)) & trim) x = trim(x)
     # if (is.fact) x = raster::as.factor(x)
+	# EJP FIXME: to be corrected for dim(x)>3:
     if(length(dim(x)) == 2) layer = x[[1]] else layer = x[[1]][, , band]
-    if (is.null(values)) {
-      # if (is.fact) {
-      #   at = x@data@attributes[[1]]$ID
-      # } else {
-      offset = diff(range(as.numeric(layer), na.rm = TRUE)) * 0.05
-      top = max(as.numeric(layer), na.rm = TRUE) + offset
-      bot = min(as.numeric(layer), na.rm = TRUE) - offset
-      values = seq(bot, top, length.out = 10)
-      values = round(values, 5)
-      # }
-    } else {
-      values = round(values, 5)
-    }
+    # if (is.null(values)) {
+    #   # if (is.fact) {
+    #   #   at = x@data@attributes[[1]]$ID
+    #   # } else {
+    #   offset = diff(range(as.numeric(layer), na.rm = TRUE)) * 0.05
+    #   top = max(as.numeric(layer), na.rm = TRUE) + offset
+    #   bot = min(as.numeric(layer), na.rm = TRUE) - offset
+    #   values = seq(bot, top, length.out = 10)
+    #   values = round(values, 5)
+    #   # }
+    # } else {
+    #   values = round(values, 5)
+    # }
     if (is.fact) {
+      ### delete at some stage!!! ###
       pal = leaflet::colorFactor(palette = col.regions,
-                                 domain = values,
+                                 domain = seq(1, length.out = length(levels(x[[1]]))),
                                  na.color = na.color)
       # pal2 = pal
     } else {
@@ -188,21 +157,26 @@ leaflet_stars = function(x,
     } else {
       grp = layer.name
     }
-    x <- sf::st_transform(x, crs = 3857)
+    # x <- sf::st_transform(x, crs = 3857)
     ## add layers to base map
-    m = addStarsImage(map = m,
-                      x = x,
-                      band = band,
-                      colors = pal,
-                      project = FALSE,
-                      opacity = alpha.regions,
-                      group = grp,
-                      layerId = grp,
-                      ...)
+    m = leafem::addStarsImage(map = m,
+                              x = x,
+                              band = band,
+                              colors = pal,
+                              project = TRUE,
+                              opacity = alpha.regions,
+                              group = grp,
+                              layerId = grp,
+                              ...)
+    m = removeLayersControl(m)
+    m = mapViewLayersControl(map = m,
+                             map.types = map.types,
+                             names = grp)
     if (label)
-      m = addImageQuery(m, x, band = band, group = grp, layerId = grp,
-                        type = query.type, digits = query.digits,
-                        position = query.position, prefix = query.prefix)
+      m = leafem::addImageQuery(m, x, band = band, group = grp, layerId = grp,
+                                project = TRUE,
+                                type = query.type, digits = query.digits,
+                                position = query.position, prefix = query.prefix)
     if (legend) {
       # stop("legend currently not supported for stars layers", call. = FALSE)
       ## add legend
@@ -211,31 +185,34 @@ leaflet_stars = function(x,
       #                         opacity = legend.opacity,
       #                         values = at,
       #                         title = grp)
-      m = addRasterLegend(x = x,
-                          map = m,
-                          title = grp,
-                          group = grp,
-                          at = at,
-                          col.regions = col.regions,
-                          na.color = na.color)
+      legend = mapviewLegend(values = as.vector(x[[1]]),
+                             colors = col.regions,
+                             at = at,
+                             na.color = col2Hex(na.color),
+                             layer.name = layer.name)
+
+      m = legend(m)
+
+      # m = addRasterLegend(x = x,
+      #                     map = m,
+      #                     title = grp,
+      #                     group = grp,
+      #                     at = at,
+      #                     col.regions = col.regions,
+      #                     na.color = na.color)
     }
-    m = mapViewLayersControl(map = m,
-                             map.types = map.types,
-                             names = grp)
+
     m = leaflet::addScaleBar(map = m, position = "bottomleft")
     m = leafem::addMouseCoordinates(m)
-    if (homebutton) m = addHomeButton(m, ext, layer.name = layer.name)
+    if (homebutton) m = leafem::addHomeButton(m, ext, group = layer.name)
     out = new('mapview', object = list(x), map = m)
     return(out)
   }
 }
 
 
-
-
-
-
 stars2Array = function(x, band = 1) {
+  # FIXME: t.b.fixed if dim(x)>3:
   if(length(dim(x)) == 2) layer = x[[1]] else layer = x[[1]][, , band]
   paste(
     sapply(seq(nrow(x[[1]])), function(i) {
